<?php

namespace Drupal\xero\Plugin\DataType;

use Drupal\Component\Utility\Html;

/**
 * Xero address type.
 *
 * @DataType(
 *   id = "xero_address",
 *   label = @Translation("Xero Address"),
 *   definition_class = "\Drupal\xero\TypedData\Definition\AddressDefinition",
 *   list_class = "\Drupal\xero\Plugin\DataType\XeroItemList"
 * )
 */
class Address extends XeroItemBase {

  /**
   * {@inheritdoc}
   */
  static public $xero_name = 'Address';

  /**
   * {@inheritdoc}
   */
  static public $plural_name = 'Addresses';

  /**
   * {@inheritdoc}
   */
  static public $label = 'AddressLine1';

  /**
   * Get the GUID property name.
   *
   * @return string
   *   The name of the Xero GUID field for this type.
   *
   * @deprecated in 8.x-1.x and is removed from 8.x-2.0. This function is unused
   *   on this data type.
   */
  public function getGUIDName() {
    return '';
  }

  /**
   * Get the label name.
   *
   * @return string
   *   The name of the Xero GUID field for this type
   *
   * @deprecated in 8.x-1.x and is removed from 8.x-2.0.
   *
   * @see \Drupal\xero\TypedData\XeroItemInterface::getXeroProperty()
   */
  public function getLabelName() {
    return 'AddressLine1';
  }

  /**
   * Get the plural name.
   *
   * @return string
   *   The name of the Xero Plural field.
   *
   * @deprecated in 8.x-1.x and is removed from 8.x-2.0.
   *
   * @see \Drupal\xero\TypedData\XeroItemInterface::getXeroProperty()
   */
  public function getPluralName() {
    return self::$plural_name;
  }

  /**
   * Gets one of the xero static properties by name.
   *
   * @param string $name
   *   The name of a static property on the class. This should be one of:
   *     - xero_name
   *     - plural_name
   *     - label_name
   *
   * @return string|NULL
   */
  public static function getXeroProperty($name) {
    if ($name === 'xero_name') {
      return self::$xero_name;
    }
    elseif ($name === 'plural_name') {
      return self::$plural_name;
    }
    elseif ($name === 'guid_name') {
      return '';
    }
    elseif ($name === 'label_name') {
      return 'AddressLine1';
    }

    throw new \InvalidArgumentException('Invalid xero property.');
  }

  /**
   * {@inheritdoc}
   */
  public function view() {
    $values = $this->getValue();
    $props = [
      'AttentionTo',
      'AddressLine1',
      'AddressLine2',
      'AddressLine3',
      'AddressLine4',
      'City',
      'Region',
      'PostalCode',
      'Country',
    ];

    $ret = [
      '#type' => 'container',
      '#prefix' => '<address>',
      '#suffix' => '</address>',
    ];

    foreach ($props as $prop) {
      if (isset($values[$prop])) {
        $suffix = !in_array($prop, ['City', 'Region']) ? '<br>' : '';
        $ret[$prop] = [
          '#markup' => Html::escape($values[$prop]) . $suffix,
        ];
      }
    }

    return $ret;
  }

}
