<?php

namespace Drupal\Tests\xero\Unit;

use Drupal\Core\Cache\NullBackend;
use Drupal\xero\XeroQuery;

/**
 * @group xero
 */
class XeroQueryClientTest extends XeroQueryTestBase {

  /**
   * Provider for client FALSE or with mocked client.
   *
   * @return array
   *   A set of arrays that contain the first argument for XeroQuery, and the
   *   expected result of XeroQuery::hasClient().
   */
  public function clientProvider() {
    return [
      [FALSE, FALSE],
      [TRUE, TRUE],
    ];
  }

  /**
   * Test XeroQuery::hasClient().
   *
   * @param bool $mockClient
   *   Whether or not to mock XeroClientInterface
   * @param bool $result
   *   The return value.
   *
   * @dataProvider clientProvider
   */
  public function testHasClient($mockClient, $result) {
    $client = (object) [
      '_serviceId' => 'xero.client',
    ];

    if ($mockClient) {
      $clientProphet = $this->prophesize('\Radcliffe\Xero\XeroClientInterface');
      $client = $clientProphet->reveal();
    }

    $cache = new NullBackend('xero_query');
    $query = new XeroQuery($client, $this->serializer, $this->typedDataManager, $this->loggerFactory, $cache);
    $this->assertEquals($result, $query->hasClient());
  }
}
