<?php

namespace Drupal\Tests\xero\Unit;

/**
 * Providers helper methods for Xero unit tests.
 *
 * This should only be used by unit tests that extend UnitTestCase or that
 * otherwise implement getRandomGenerator().
 */
trait XeroTestHelperTrait {

  /**
   * Create a Guid with or without curly braces.
   *
   * @param bool $braces
   *   (Optional) Return Guid wrapped in curly braces.
   *
   * @return string
   *   Guid string.
   */
  protected function createGuid($braces = TRUE) {
    $hash = strtolower(hash('ripemd128', md5($this->getRandomGenerator()->string(100))));
    $guid = substr($hash, 0, 8) . '-' . substr($hash, 8, 4) . '-' . substr($hash, 12, 4);
    $guid .= '-' . substr($hash, 16, 4) . '-' . substr($hash, 20, 12);

    if ($braces) {
      return '{' . $guid . '}';
    }

    return $guid;
  }

  /**
   * Create a mock consumer key or secret.
   *
   * @return string
   *   A 30 character string that can be used as a consumer key or secret.
   */
  protected function createToken() {
    return strtoupper(hash('ripemd128', md5($this->getRandomGenerator()->string(30))));
  }

}
